Running unit tests
------------------

To run unit tests, in the root directory of `beluga`, do::

    $ python -m pytest beluga/

to run the "fast" test cases. To run the full set of test cases, including full example problems, do::

    $ python -m pytest
